@@ -52,12 +52,15 @@ class DiscretizeRegGrid(ProblemWrapper):
         base_problem,
         deltas,
         fd_order=1,
-        fd_bounds_order=None,
+        fd_bounds_order=1,
         mem_size=1000,
         **dpars,
     ):
         super().__init__(base_problem, base_problem.name + "_grid")
 
+        if isinstance(deltas, float):
+            deltas = {v: deltas for v in base_problem.var_names_float()}
+
         self.grid = None
         self._deltas = deltas
         self._msize = mem_size
@@ -439,3 +442,61 @@ class DiscretizeRegGrid(ProblemWrapper):
                 np.einsum("pgo,pg->po", objs, coeffs),
                 np.einsum("pgc,pg->pc", cons, coeffs),
             )
+
+    def finalize_individual(self, vars_int, vars_float, verbosity=1):
+        """
+        Finalization, given the champion data.
+
+        Parameters
+        ----------
+        vars_int : np.array
+            The optimal integer variable values, shape: (n_vars_int,)
+        vars_float : np.array
+            The optimal float variable values, shape: (n_vars_float,)
+        verbosity : int
+            The verbosity level, 0 = silent
+
+        Returns
+        -------
+        problem_results : Any
+            The results of the variable application
+            to the problem
+        objs : np.array
+            The objective function values, shape: (n_objectives,)
+        cons : np.array
+            The constraints values, shape: (n_constraints,)
+
+        """
+        if self._msize is not None:
+            self.memory.clear()
+        return self.base_problem.finalize_individual(vars_int, vars_float, verbosity)
+
+    def finalize_population(self, vars_int, vars_float, verbosity=0):
+        """
+        Finalization, given the final population data.
+
+        Parameters
+        ----------
+        vars_int : np.array
+            The integer variable values of the final
+            generation, shape: (n_pop, n_vars_int)
+        vars_float : np.array
+            The float variable values of the final
+            generation, shape: (n_pop, n_vars_float)
+        verbosity : int
+            The verbosity level, 0 = silent
+
+        Returns
+        -------
+        problem_results : Any
+            The results of the variable application
+            to the problem
+        objs : np.array
+            The final objective function values, shape: (n_pop, n_components)
+        cons : np.array
+            The final constraint values, shape: (n_pop, n_constraints)
+
+        """
+        if self._msize is not None:
+            self.memory.clear()
+        return self.base_problem.finalize_population(vars_int, vars_float, verbosity)
